django-iban
===========

A validated Django model field for [International Bank Account Numbers](https://en.wikipedia.org/wiki/International_Bank_Account_Number) (IBAN).

I'm not sure if this should be a stand-alone app or be submitted to Django
local flavor. In the mean time, the code is available for use. Pull requests
happily accepted.

License: 3-clause BSD
